@@ -1,7 +1,11 @@
 ## ---- echo = FALSE, message = FALSE, warning = FALSE---------------------
 knitr::opts_chunk$set(message = FALSE,
                       warning = FALSE,
-                      fig.width = 6)
+                      fig.width = 8, 
+                      fig.height = 4.5,
+                      fig.align = 'center',
+                      out.width='95%', 
+                      dpi = 200)
 # devtools::load_all() # Travis CI fails on load_all()
 
 ## ------------------------------------------------------------------------
@@ -130,12 +134,15 @@ wti_price_usd <- tq_get("DCOILWTICO", get = "economic.data")
 wti_price_usd 
 
 ## ------------------------------------------------------------------------
-eur_usd <- tq_get("EUR/USD", get = "exchange.rates", from = "2000-01-01")
+eur_usd <- tq_get("EUR/USD", 
+                  get = "exchange.rates", 
+                  from = Sys.Date() - lubridate::days(10))
 eur_usd 
 
 ## ------------------------------------------------------------------------
 plat_price_eur <- tq_get("plat", get = "metal.prices", 
-                         from = "2000-01-01", base.currency = "EUR")
+                         from = Sys.Date() - lubridate::days(10),
+                         base.currency = "EUR")
 plat_price_eur 
 
 ## ------------------------------------------------------------------------
