@@ -1,7 +1,11 @@
 ## ---- echo = FALSE, message = FALSE, warning = FALSE---------------------
 knitr::opts_chunk$set(message = FALSE,
                       warning = FALSE,
-                      fig.width = 6)
+                      fig.width = 8, 
+                      fig.height = 4.5,
+                      fig.align = 'center',
+                      out.width='95%', 
+                      dpi = 200)
 # devtools::load_all() # Travis CI fails on load_all()
 
 ## ------------------------------------------------------------------------
